<?php
/**
 * Plugin Name: Bin Accessibility
 * Plugin URI: https://berginformatik.ch/plugins/bin-accessibility
 * Description: Accessibility Toolbar integration for any Theme. Change Font Size, activate High Contrast or Simple View Mode. Enable the Direct Print Button and add Buttons to link a Document in Simple Language or add a Button to link a Sign Language Page.
 * Version: 1.0.2
 * Author: Berg Informatik
 * Author URI: https://berginformatik.ch
 */

if(!defined('ABSPATH')) { exit; }

define('BIN_ACCESSIBILITY_VERSION', '1.0.2');
define('BIN_ACCESSIBILITY_DIR', dirname(__FILE__));
define('BIN_ACCESSIBILITY_URL', plugins_url('', __FILE__));

require_once BIN_ACCESSIBILITY_DIR.'/bin-accessibility.register.php';
require_once BIN_ACCESSIBILITY_DIR.'/bin-accessibility.settings.php';

// On plugin activation
register_activation_hook(__FILE__, 'bin_accessibility_activation');
function bin_accessibility_activation()
{
	BinAccessibility_Register::activate();
}

// On plugin deactivation
register_deactivation_hook(__FILE__, 'bin_accessibility_deactivation');
function bin_accessibility_deactivation()
{
	BinAccessibility_Register::deactivate();
}

// On plugin remove
register_uninstall_hook(__FILE__, 'bin_accessibility_uninstall');
function bin_accessibility_uninstall()
{
	BinAccessibility_Register::uninstall();
}

// Run plugin
add_action('plugins_loaded', 'initBinAccessiblity');
function initBinAccessiblity()
{
	new BinAccessibility;
	new BinAccessibility_Settings;
}

class BinAccessibility
{
    function __construct()
	{
        add_action('init', [$this, 'load_textdomain']);
		add_action('admin_enqueue_scripts', [$this, 'admin_enqueue_scripts']);
		add_action('wp_enqueue_scripts', [$this, 'wp_enqueue_scripts']);
		add_action('wp_footer', [$this, 'wp_footer']);
	}
	
	/**
	 * load textdomain
	 */
	function load_textdomain()
	{
		// vars
		$domain = 'bin-accessibility';
		$locale = is_admin() && function_exists('get_user_locale') ? get_user_locale() : get_locale();
		$mofile = $domain.'-'.$locale.'.mo';

		// load from the languages directory first
		load_textdomain($domain, WP_LANG_DIR.'/plugins/'.$mofile);

		// redirect missing translations
		$mofile = str_replace('de_DE', 'de_CH', $mofile);

		// load from plugin lang folder
		$loaded = load_textdomain($domain, BIN_ACCESSIBILITY_DIR.'/languages/'.$mofile);
	}

	function admin_enqueue_scripts()
	{
		wp_enqueue_media();
		wp_enqueue_script('bin-accessibility-admin', BIN_ACCESSIBILITY_URL.'/js/admin.js', ['jquery'], BIN_ACCESSIBILITY_VERSION, true);
		wp_enqueue_style('bin-accessibility-admin', BIN_ACCESSIBILITY_URL.'/css/admin.css', false, BIN_ACCESSIBILITY_VERSION);
	}
	
	function wp_enqueue_scripts()
	{
		if(get_option('bin_accessibility_enable'))
		{
			wp_enqueue_script('js-cookie', BIN_ACCESSIBILITY_URL.'/js/js-cookie.min.js', ['jquery'], '2.2.0', true);
			wp_register_script('bin-accessibility-front', BIN_ACCESSIBILITY_URL.'/js/front.js', ['jquery', 'js-cookie'], BIN_ACCESSIBILITY_VERSION, true);
			wp_localize_script('bin-accessibility-front', 'local', [
				'max' => __('Maximum font size reached.', 'bin-accessibility'),
				'min' => __('Minimum font size reached.', 'bin-accessibility'),
				'default' => esc_attr(get_option('bin_accessibility_default_fontsize'))
			]);
			wp_enqueue_script('bin-accessibility-front');
			wp_enqueue_style('bin-accessibility-front', BIN_ACCESSIBILITY_URL.'/css/front.css', false, BIN_ACCESSIBILITY_VERSION);
		}
	}
	
	function wp_footer()
	{
		if(get_option('bin_accessibility_enable'))
		{
			echo self::accessibilityToolbar();
		}
	}
	
	static function accessibilityToolbar()
	{
		$string = '';
		
		$string .= '<div id="accessibility-toolbar-backdrop"></div>';
		$string .= '<div id="accessibility-toolbar">';
			$string .= '<div class="accessibility-toolbar-wrapper">';
				$string .= '<div class="accessibility-toolbar-meta">';
					if(get_option('bin_accessibility_fontsize')) { $string .= '<div class="accessibility-fontsize">'.__('Font Size', 'bin-accessibility').': <span class="js-accessibility-fontsize accessibility-fontsize-value accessibility-badge" title="'.__('Reset to default font size', 'bin-accessibility').'">16px</span></div>'; }
					if(get_option('bin_accessibility_contrast')) { $string .= '<div class="accessibility-contrast">'.__('High Contrast', 'bin-accessibility').': <span class="js-accessibility-contrast accessibility-contrast-off accessibility-badge accessibility-badge-red" title="'.__('Toggle high contrast on', 'bin-accessibility').'">'.__('off', 'bin-accessibility').'</span><span class="js-accessibility-contrast accessibility-contrast-on accessibility-badge accessibility-badge-green" title="'.__('Toggle high contrast off', 'bin-accessibility').'">'.__('on', 'bin-accessibility').'</span></div>'; }
					if(get_option('bin_accessibility_simplified')) { $string .= '<div class="accessibility-simplified">'.__('Simple View', 'bin-accessibility').': <span class="js-accessibility-simplified accessibility-simplified-off accessibility-badge accessibility-badge-red" title="'.__('Toggle simplified version on', 'bin-accessibility').'">'.__('off', 'bin-accessibility').'</span><span class="js-accessibility-simplified accessibility-simplified-on accessibility-badge accessibility-badge-green" title="'.__('Toggle simplified version off', 'bin-accessibility').'">'.__('on', 'bin-accessibility').'</span></div>'; }
				$string .= '</div>';
				$string .= '<div class="accessibility-toolbar-info"></div>';
				$string .= '<div class="accessibility-toolbar-buttons">';
					if(get_option('bin_accessibility_fontsize')) { $string .= '<div><a href="javascript:void(0);" class="js-accessibility-font-minus accessibility-button accessibility-button-font-minus" title="'.__('Reduce font size', 'bin-accessibility').'"><span class="accessibility-button-icon">A-</span><span class="accessibility-button-title">'.__('Reduce font size', 'bin-accessibility').'</span></a></div>'; }
					if(get_option('bin_accessibility_fontsize')) { $string .= '<div><a href="javascript:void(0);" class="js-accessibility-font-plus accessibility-button accessibility-button-font-plus" title="'.__('Increase font size', 'bin-accessibility').'"><span class="accessibility-button-icon">A+</span><span class="accessibility-button-title">'.__('Increase font size', 'bin-accessibility').'</span></a></div>'; }
					if(get_option('bin_accessibility_contrast')) { $string .= '<div><a href="javascript:void(0);" class="js-accessibility-contrast accessibility-button accessibility-button-contrast" title="'.__('High contrast', 'bin-accessibility').'"><span class="accessibility-button-icon"></span><span class="accessibility-button-title">'.__('High contrast', 'bin-accessibility').'</span></a></div>'; }
					if(get_option('bin_accessibility_simplified')) { $string .= '<div><a href="javascript:void(0);" class="js-accessibility-simplified accessibility-button accessibility-button-simplified" title="'.__('Simplified view', 'bin-accessibility').'"><span class="accessibility-button-icon"></span><span class="accessibility-button-title">'.__('Simplified view', 'bin-accessibility').'</span></a></div>'; }
					if(get_option('bin_accessibility_print')) { $string .= '<div><a href="javascript:print();" class="accessibility-button accessibility-button-print" title="'.__('Print page', 'bin-accessibility').'"><span class="accessibility-button-icon"></span><span class="accessibility-button-title">'.__('Print page', 'bin-accessibility').'</h4></a></div>'; }
					if(get_option('bin_accessibility_simplelanguage')) { $string .= '<div><a href="'.esc_url(get_option('bin_accessibility_simplelanguage')).'" target="_blank" class="accessibility-button accessibility-button-pdf" title="'.__('Simple language', 'bin-accessibility').'"><span class="accessibility-button-icon"></span><span class="accessibility-button-title">'.__('Simple language', 'bin-accessibility').'</span></a></div>'; }
					if(get_option('bin_accessibility_singlanguage')) { $string .= '<div><a href="'.esc_url(get_option('bin_accessibility_singlanguage')).'" target="_blank" class="accessibility-button accessibility-button-signlanguage" title="'.__('Sign language video', 'bin-accessibility').'"><span class="accessibility-button-icon"></span><span class="accessibility-button-title">'.__('Sign language video', 'bin-accessibility').'</span></a></div>'; }
				$string .= '</div>';
				if(get_option('bin_accessibility_cookie')) { $string .= '<div class="accessibility-toolbar-cookie">'.esc_html(get_option('bin_accessibility_cookie')).'</div>'; }
				$string .= '<a class="js-show-accessibility btn-show-accessibility" href="javascript:void(0);" title="'.__('Show accessibility toolbar', 'bin-accessibility').'"></a>';
			$string .= '</div>';
		$string .= '</div>';
		
		return $string;
	}
}